# bbtools

**DOI:** [10.5281/zenodo.5812101](https://doi.org/10.5281/zenodo.5812101)

## Available Versions
- **Version 38.94.0**
  - [Download](https://zenodo.org/record/5812102/files/bbtools_38.94.0.img)
  - **MD5:** `fd5be1b87f26419953b9754e6acd47f6`
  - **DOI:** [10.5281/zenodo.5812102](https://doi.org/10.5281/zenodo.5812102)
  - **Size:** 65.88 MB
  - **Binaries:** 0 available

## Binaries (196 total)

```crosscontaminate.sh kmerposition.sh runhmm.sh a_sample_mt.sh cutgff.sh kmutate.sh samtoroc.sh addadapters.sh cutprimers.sh seal.sh addssu.sh decontaminate.sh lilypad.sh sendsketch.sh adjusthomopolymers.sh dedupe.sh loadreads.sh shred.sh alltoall.sh dedupe2.sh loglog.sh shrinkaccession.sh analyzeaccession.sh dedupebymapping.sh makechimeras.sh shuffle.sh analyzegenes.sh demuxbyname.sh makecontaminatedgenomes.sh shuffle2.sh analyzesketchresults.sh diskbench.sh makepolymers.sh sketch.sh applyvariants.sh estherfilter.sh mapPacBio.sh sketchblacklist.sh bbcms.sh explodetree.sh matrixtocolumns.sh sketchblacklist2.sh bbcountunique.sh fetchproks.sh mergeOTUs.sh sortbyname.sh bbduk.sh filterassemblysummary.sh mergebarcodes.sh splitbytaxa.sh bbest.sh filterbarcodes.sh mergepgm.sh splitnextera.sh bbfakereads.sh filterbycoverage.sh mergeribo.sh splitribo.sh filterbyname.sh mergesam.sh splitsam.sh bbmap.sh filterbysequence.sh mergesketch.sh splitsam4way.sh bbmapskimmer.sh filterbytaxa.sh mergesorted.sh splitsam6way.sh bbmask.sh filterbytile.sh msa.sh stats.sh bbmerge-auto.sh filterlines.sh mutate.sh statswrapper.sh bbmerge.sh filterqc.sh muxbyname.sh streamsam.sh bbnorm.sh filtersam.sh partition.sh subsketch.sh bbrealign.sh filtersilva.sh phylip2fasta.sh summarizecontam.sh bbrename.sh filtersubs.sh pileup.sh summarizecoverage.sh bbsketch.sh filtervcf.sh plotflowcell.sh summarizecrossblock.sh bbsplit.sh fixgaps.sh plotgc.sh summarizemerge.sh bbsplitpairs.sh fungalrelease.sh postfilter.sh summarizequast.sh bbstats.sh fuse.sh printtime.sh summarizescafstats.sh bbversion.sh gbff2gff.sh processfrag.sh summarizeseal.sh bbwrap.sh getreads.sh processhi-c.sh summarizesketch.sh gi2ancestors.sh processspeed.sh synthmda.sh bloomfilter.sh gi2taxid.sh randomgenome.sh tadpipe.sh gitable.sh randomreads.sh tadpole.sh calcmem.sh grademerge.sh readlength.sh tadwrapper.sh calctruequality.sh gradesam.sh readqc.sh taxonomy.sh callgenes.sh icecreamfinder.sh reducesilva.sh taxserver.sh callpeaks.sh icecreamgrader.sh reformat.sh taxsize.sh callvariants.sh icecreammaker.sh reformatpb.sh taxtree.sh callvariants2.sh idmatrix.sh removebadbarcodes.sh testfilesystem.sh clumpify.sh idtree.sh removecatdogmousehuman.sh testformat.sh commonkmers.sh invertkey.sh removehuman.sh testformat2.sh comparegff.sh kapastats.sh removehuman2.sh tetramerfreq.sh comparesketch.sh kcompress.sh removemicrobes.sh textfile.sh comparessu.sh keepbestcopy.sh removesmartbell.sh translate6frames.sh comparevcf.sh khist.sh rename.sh unicode2ascii.sh consect.sh kmercountexact.sh renameimg.sh unzip.sh consensus.sh kmercountmulti.sh repair.sh vcf2gff.sh countbarcodes.sh kmercoverage.sh replaceheaders.sh webcheck.sh countgc.sh kmerfilterset.sh representative.sh countsharedlines.sh kmerlimit.sh rqcfilter.sh crossblock.sh kmerlimit2.sh rqcfilter2.sh```
